@@ -539,7 +539,7 @@ class ArgparseCompleter:
         # Check if there are too many CompletionItems to display as a table
         if len(completions) <= self._cmd2_app.max_completion_items:
             # If a metavar was defined, use that instead of the dest field
-            destination = arg_state.action.metavar if arg_state.action.metavar else arg_state.action.dest
+            destination = arg_state.action.metavar or arg_state.action.dest
 
             # Handle case where metavar was a tuple
             if isinstance(destination, tuple):
@@ -587,7 +587,7 @@ class ArgparseCompleter:
             # Generate the hint table string
             console = Cmd2GeneralConsole()
             with console.capture() as capture:
-                console.print(hint_table, end="")
+                console.print(hint_table, end="", soft_wrap=False)
             self._cmd2_app.formatted_completions = capture.get()
 
         # Return sorted list of completions
